@@ -9,6 +9,7 @@ use std::collections::HashMap;
 use k8s_openapi::api::core::v1::{ConfigMap, Namespace, Node, Pod, Secret};
 use kube::api::{self, Api};
 // use kube::api::{Api, ListParams, PostParams, Resource, WatchEvent};
+use kube::config::Kubeconfig;
 use kube::{Client, ResourceExt};
 use serde_json as json;
 
@@ -27,6 +28,7 @@ const KUBE_SYSTEM_NS: &str = "kube-system";
 const STATEHUB_CLUSTER_TOKEN_SECRET_TYPE: &str = "statehub.io/cluster-token";
 const STATEHUB_CLUSTER_TOKEN_SECRET_NAME: &str = "statehub-cluster-token";
 const STATEHUB_CLUSTER_CONFIGMAP_NAME: &str = "statehub";
+const CLUSTER_DELIMITER: char = '/';
 
 pub(crate) struct Kubectl {
     client: Client,
@@ -83,8 +85,9 @@ impl Kubectl {
     async fn create_configmap(
         &self,
         name: &str,
-        cluster_id: &v1::ClusterName,
-        default_storage_class: &str,
+        cluster_name: &v1::ClusterName,
+        default_state: &str,
+        api: &str,
     ) -> anyhow::Result<ConfigMap> {
         let configmaps = self.configmaps();
         let configmap = json::from_value(json::json!({
@@ -95,8 +98,9 @@ impl Kubectl {
                 "namespace": self.namespace,
             },
             "data": {
-                "cluster-id": cluster_id,
-                "default-storage-class": default_storage_class,
+                "cluster-name": cluster_name,
+                "default-state": default_state,
+                "api-url": api,
             }
         }))?;
         let pp = self.post_params();
@@ -248,7 +252,8 @@ pub(crate) async fn list_pods() -> anyhow::Result<impl IntoIterator<Item = Pod>>
 pub(crate) async fn store_configmap(
     namespace: &str,
     cluster_name: &v1::ClusterName,
-    default_storage_class: &str,
+    default_state: &str,
+    api: &str,
 ) -> anyhow::Result<ConfigMap> {
     let kube = Kubectl::with_namespace(namespace).await?;
 
@@ -263,7 +268,8 @@ pub(crate) async fn store_configmap(
     kube.create_configmap(
         STATEHUB_CLUSTER_CONFIGMAP_NAME,
         cluster_name,
-        default_storage_class,
+        default_state,
+        api,
     )
     .await
 }
@@ -300,11 +306,27 @@ pub(crate) fn extract_cluster_token(secret: &Secret) -> Option<Cow<'_, str>> {
         .map(String::from_utf8_lossy)
 }
 
-pub(crate) fn get_default_cluster_name() -> Option<v1::ClusterName> {
-    None
-}
-
 // TODO: implement provider fetch out of cluster
 pub(crate) fn get_cluster_provider(_cluster: &v1::ClusterName) -> v1::Provider {
     v1::Provider::Generic
 }
+
+pub(crate) fn get_cluster_name() -> Option<v1::ClusterName> {
+    let config = Kubeconfig::read().ok()?;
+    let contexts = config.contexts;
+    let clusters = config.clusters;
+    config
+        .current_context
+        .or_else(|| contexts.into_iter().next().map(|context| context.name))
+        .or_else(|| clusters.into_iter().next().map(|cluster| cluster.name))
+        .map(rsplit_slash)
+        .map(v1::ClusterName)
+}
+
+fn rsplit_slash(text: String) -> String {
+    if let Some((_, name)) = text.rsplit_once(CLUSTER_DELIMITER) {
+        name.to_string()
+    } else {
+        text
+    }
+}
